@@ -15,17 +15,13 @@
 # ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 # OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
+
 from http.server import HTTPServer, BaseHTTPRequestHandler
 from jinja2 import __version__ as jinja2_version
 import jinjafx, os, io, sys, socket, signal, threading, yaml, json, base64, time, datetime
-import re, argparse, zipfile, hashlib, traceback, glob, hmac, uuid, struct, binascii, gzip
+import re, argparse, zipfile, hashlib, traceback, glob, hmac, uuid, struct, binascii, gzip, requests
 
-__version__ = '21.12.3'
-
-try:
-  import requests
-except:
-  pass
+__version__ = '22.1.2'
 
 try:
   from ansible.constants import DEFAULT_VAULT_ID_MATCH
@@ -35,6 +31,8 @@ except:
   pass
 
 lock = threading.RLock()
+base = os.path.abspath(os.path.dirname(__file__))
+os.chdir(base + '/extensions')
 
 aws_s3_url = None
 aws_access_key = None
@@ -142,8 +140,6 @@ class JinjaFxRequest(BaseHTTPRequestHandler):
       r = [ 'text/plain', 200, 'OK\r\n'.encode('utf-8'), sys._getframe().f_lineno ]
 
     elif not api_only:
-      base = os.path.abspath(os.path.dirname(__file__))
-
       if fpath == '/':
         fpath = '/index.html'
 
@@ -331,6 +327,12 @@ class JinjaFxRequest(BaseHTTPRequestHandler):
                 if y != None:
                   gvars.update(y)
   
+              if 'jinja2_extensions' in gvars:
+                gvars['jinja2_extensions'].append('jinjafx_extension.JinjaFxExtension')
+
+              else:
+                gvars['jinja2_extensions'] = ['jinjafx_extension.JinjaFxExtension']
+
               st = round(time.time() * 1000)
               outputs = jinjafx.JinjaFx().jinjafx(template, data, gvars, 'Output')
               ocount = 0
@@ -706,8 +708,6 @@ def main(rflag=[0]):
     verbose = args.v
     
     if args.s3 is not None:
-      import requests
-
       aws_s3_url = args.s3
       aws_access_key = os.getenv('AWS_ACCESS_KEY')
       aws_secret_key = os.getenv('AWS_SECRET_KEY')
